@@ -2,19 +2,21 @@
 reference the aio-pika.pool
 '''
 import asyncio
-from aio_pika.pool import PoolInvalidStateError, ConstructorType
-from typing import Union, AsyncContextManager
-from .excs import ClientError
+from typing import AsyncContextManager, Optional, Any
 
-NumType = Union[int, float]
+from aio_pika.types import TimeoutType
+from aio_pika.pool import PoolInvalidStateError, ConstructorType
+
+from .excs import ClientError
 
 
 class ProxyPool(object):
     _inited = False
 
     def __init__(self, proxy_factory: ConstructorType,
-                 pool_size: int = None, initial_size: int = None, time_out: NumType = None,
-                 loop: asyncio.AbstractEventLoop = None):
+                 pool_size: Optional[int] = None, initial_size: Optional[int] = None,
+                 time_out: Optional[TimeoutType] = None,
+                 loop: Optional[asyncio.AbstractEventLoop] = None):
         self.loop = loop or asyncio.get_event_loop()
         # if the origin proxy_factory need some args, you can use functools.partial or functools.partialmethod
         self._proxy_factory = proxy_factory
@@ -27,14 +29,15 @@ class ProxyPool(object):
         self._initial_size = initial_size or 0
         self._time_out = time_out
 
-    async def init_proxies(self):
-        self._inited = True
-        for i in range(self._initial_size):
-            proxy = await self._create_proxy()
-            self.release_proxy(proxy)
+    async def init_proxies(self) -> None:
+        if not self._inited:
+            self._inited = True
+            for i in range(self._initial_size):
+                proxy = await self._create_proxy()
+                self.release_proxy(proxy)
 
     @property
-    def _has_released(self):
+    def _has_released(self) -> bool:
         return self._free_proxies.qsize() > 0
 
     @property
@@ -43,7 +46,7 @@ class ProxyPool(object):
             return self._created >= self._pool_size or self._has_released
         return self._has_released
 
-    async def _create_proxy(self):
+    async def _create_proxy(self) -> Any:
         if self._closed:
             raise PoolInvalidStateError('create proxy operation on closed pool')
 
@@ -62,7 +65,7 @@ class ProxyPool(object):
             self._created_proxies.add(proxy)
             return proxy
 
-    async def get_proxy(self):
+    async def get_proxy(self) -> Any:
         if self._closed:
             raise PoolInvalidStateError('get operation on closed pool')
         if self._is_overflow:
@@ -75,12 +78,12 @@ class ProxyPool(object):
             return await self._free_proxies.get()
         return await self._create_proxy()
 
-    def release_proxy(self, proxy):
+    def release_proxy(self, proxy: Any) -> None:
         if self._closed:
             raise PoolInvalidStateError('put proxy operation on closed pool')
         self._free_proxies.put_nowait(proxy)
 
-    async def close(self):
+    async def close(self) -> None:
         async with self._lock:
             self._closed = True
             tasks = []
@@ -91,7 +94,7 @@ class ProxyPool(object):
             if tasks:
                 await asyncio.gather(*tasks, return_exceptions=True)
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> "ProxyPool":
         return self
 
     async def __aexit__(self, exc_type, exc_val, exc_tb):
@@ -108,11 +111,11 @@ class ProxyPool(object):
 
 class PoolItemContextManager(AsyncContextManager):
 
-    def __init__(self, pool):
+    def __init__(self, pool: ProxyPool):
         self.pool = pool
         self.item = None
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> Any:
         # noinspection PyProtectedMember
         self.item = await self.pool.get_proxy()
         return self.item
